@@ -233,7 +233,8 @@ typedef enum {
 	GTK_HTML_CURSOR_SKIP_ONE,
 	GTK_HTML_CURSOR_SKIP_WORD,
 	GTK_HTML_CURSOR_SKIP_PAGE,
-	GTK_HTML_CURSOR_SKIP_ALL
+	GTK_HTML_CURSOR_SKIP_ALL,
+	GTK_HTML_CURSOR_SKIP_NONE
 } GtkHTMLCursorSkipType;
 
 typedef enum {
